package cn.iocoder.yudao.module.order.service.order;

import java.util.*;
import javax.validation.*;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.IService;
import cn.iocoder.yudao.module.order.dal.dataobject.orderDeparture.OrderDepartureDO;
import cn.iocoder.yudao.module.order.vo.orderObjective.*;
import cn.iocoder.yudao.module.order.dal.dataobject.orderObjective.OrderObjectiveDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

/**
 * 订单目的仓库 Service 接口
 *
 * @author 系统管理员
 */
public interface OrderObjectiveService extends IService<OrderObjectiveDO> {

    /**
     * 创建订单目的仓库
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createOrderObjective(@Valid OrderObjectiveCreateReqVO createReqVO);

    /**
     * 更新订单目的仓库
     * @param updateReqVO 更新信息
     */
    void updateOrderObjective(@Valid OrderObjectiveUpdateReqVO updateReqVO);

    /**
     * 删除订单目的仓库
     * @param id 编号
     */
    void deleteOrderObjective(Long id);

    /**
     * 获得订单目的仓库
     * @param id 编号
     * @return 订单目的仓库
     */
    OrderObjectiveDO getOrderObjective(Long id);

    /**
     * 获得订单目的仓库列表
     * @param ids 编号
     * @return 订单目的仓库列表
     */
    List<OrderObjectiveDO> getOrderObjectiveList(Collection<Long> ids);

    /**
     * 获得订单目的仓库分页
     * @param page 分页查询
     * @param query 查询
     * @return 订单目的仓库分页
     */
    PageResult<OrderObjectiveDO> getOrderObjectivePage(OrderObjectiveQueryVO query, PageVO page);

    /**
     * 获得订单目的仓库列表, 用于 Excel 导出
     * @param query 查询
     * @return 订单目的仓库列表
     */
    List<OrderObjectiveDO> getOrderObjectiveList(OrderObjectiveQueryVO query);

    OrderObjectiveDO getByOrderId(Long orderId);

    List<OrderObjectiveDO> getByOrderIdList(List<Long> orderIdList);
}
