package cn.iocoder.yudao.module.order.service.orderPickup;

import java.util.*;
import javax.validation.*;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.IService;
import cn.iocoder.yudao.module.order.vo.orderPickup.*;
import cn.iocoder.yudao.module.order.dal.dataobject.orderPickup.OrderPickupDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;

/**
 * 提货 Service 接口
 *
 * @author 系统管理员
 */
public interface OrderPickupService extends IService<OrderPickupDO> {

    /**
     * 创建提货
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createOrderPickup(@Valid OrderPickupCreateReqVO createReqVO);

    /**
     * 更新提货
     * @param updateReqVO 更新信息
     */
    void updateOrderPickup(@Valid OrderPickupUpdateReqVO updateReqVO);

    /**
     * 删除提货
     * @param id 编号
     */
    void deleteOrderPickup(Long id);

    /**
     * 获得提货
     * @param id 编号
     * @return 提货
     */
    OrderPickupDO getOrderPickup(Long id);

    /**
     * 获得提货列表
     * @param ids 编号
     * @return 提货列表
     */
    List<OrderPickupDO> getOrderPickupList(Collection<Long> ids);

    /**
     * 获得提货分页
     * @param page 分页查询
     * @param query 查询
     * @return 提货分页
     */
    PageResult<OrderPickupDO> getOrderPickupPage(OrderPickupQueryVO query, PageVO page);

    /**
     * 获得提货列表, 用于 Excel 导出
     * @param query 查询
     * @return 提货列表
     */
    List<OrderPickupDO> getOrderPickupList(OrderPickupQueryVO query);

    void createBatchOrderPickup(List<OrderPickupCreateReqVO> createReqVOList);

    List<OrderPickupBackVO> getPickUpListByOrderNo(String orderIds);

    void createSplitBatch(List<OrderPickupCreateReqVO> createReqVOList);

    List<OrderPickupDO> getAllPickUpListByOrderNo(String orderNo);
}
